from setuptools import setup

setup(name='tri_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['tri_distributions'],
      author= 'Andrew Doan',
      author_email= 'tri.sidoan@gmail.com',
      zip_safe=False)
